@@ -1,13 +1,20 @@
 import imghdr
 
 from mitmproxy.contentviews import base
-from mitmproxy.types import multidict
+from mitmproxy.coretypes import multidict
 from . import image_parser
 
 
+def test_ico(h, f):
+    if h.startswith(b"\x00\x00\x01\x00"):
+        return "ico"
+
+
+imghdr.tests.append(test_ico)
+
+
 class ViewImage(base.View):
     name = "Image"
-    prompt = ("image", "i")
 
     # there is also a fallback in the auto view for image/*.
     content_types = [
@@ -27,6 +34,8 @@ class ViewImage(base.View):
             image_metadata = image_parser.parse_gif(data)
         elif image_type == 'jpeg':
             image_metadata = image_parser.parse_jpeg(data)
+        elif image_type == 'ico':
+            image_metadata = image_parser.parse_ico(data)
         else:
             image_metadata = [
                 ("Image Format", image_type or "unknown")
